Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/matrix.py
    :caption: examples/matrix.py
    :linenos:

.. literalinclude:: ../examples/segments.py
    :caption: examples/segments.py
    :linenos:
